@@ -54,6 +54,7 @@ def get_version():
     version_file = os.path.abspath(os.path.join(os.path.dirname(__file__), 'lib', 'data', 'VERSION'))
     with open(version_file, 'r') as v_file:
         version = v_file.read()
+    version = version.strip()
     return version
 
 
@@ -268,7 +269,7 @@ class Client():
             config.set('DEPLOYMENT_SERVICES', True)
 
             # Generate TeSLA Database configuration
-            config.set('DB_HOST', domain)
+            config.set('DB_HOST', 'database')
             config.set('DB_NAME', 'tesla')
             config.set('DB_USER', 'tesla')
             config.set('DB_ROOT_PASSWORD', uuid.uuid4().__str__())
@@ -282,7 +283,7 @@ class Client():
             config.set('VAULT_DB_PASSWORD', uuid.uuid4().__str__())
 
             # Generate Redis configuration
-            config.set('REDIS_HOST', domain)
+            config.set('REDIS_HOST', 'redis')
             config.set('REDIS_PASSWORD', uuid.uuid4().__str__())
 
             # Generate MinIO configuration
@@ -296,24 +297,23 @@ class Client():
             config.set('RABBITMQ_ADMIN_PASSWORD', uuid.uuid4().__str__())
 
             # Generate Celery configuration
-            config.set('CELERY_BROKER_HOST', domain)
+            config.set('CELERY_BROKER_HOST', 'rabbitmq')
             config.set('CELERY_BROKER_PORT', config.get('RABBITMQ_PORT'))
             config.set('CELERY_BROKER_USER', config.get('RABBITMQ_ADMIN_USER'))
             config.set('CELERY_BROKER_PASSWORD', config.get('RABBITMQ_ADMIN_PASSWORD'))
 
         # If Moodle is included, generate credentials and configuration
-        if deploy_external_services:
+        if deploy_moodle:
             # Enable the moodle flag
             config.set('MOODLE_DEPLOY', True)
 
             # Generate Moodle Database configuration
-            config.set('MOODLE_DB_HOST', domain)
+            config.set('MOODLE_DB_HOST', config.get('DB_HOST'))
             config.set('MOODLE_DB_PASSWORD', uuid.uuid4().__str__())
 
             # Generate Moodle administrator password
             config.set('MOODLE_ADMIN_PASSWORD', uuid.uuid4().__str__())
 
-
         # Write the configuration file to disk
         with open(output_file, 'w') as out_fh:
             config.write(out_fh)
@@ -322,7 +322,6 @@ class Client():
         """
             Check the current configuration
 
-            :param config: Configuration object
             :return: Report of the configuration check
             :rtype: dict
         """
@@ -590,6 +589,23 @@ class Client():
                 scopes.append('/api/v2/institution/{}/ic/*'.format(
                     inst_user.institution_id
                 ))
+            if 'LEARNER' in models.user.get_institution_roles(user):
+                learner_id = str(inst_user.learner.learner_id)
+                scopes.append('/lapi/v1/enrolment/{}/{}/'.format(
+                    inst_user.institution_id,
+                    learner_id
+                ))
+                scopes.append('/lapi/v1/status/{}/{}/'.format(
+                    inst_user.institution_id,
+                    learner_id
+                ))
+                scopes.append('/lapi/v1/alert/{}/{}/'.format(
+                    inst_user.institution_id,
+                    learner_id
+                ))
+                scopes.append('/api/v2/institution/{}/learner/{}/*'.format(
+                    inst_user.institution_id, inst_user.id
+                ))
             token_pair = self.get_user_token_pair(user=inst_user, scope=scopes, ttl=15, max_ttl=24*60)
         else:
             raise TeslaAuthException('Invalid user. Missing Institution or administration rights.')
@@ -732,7 +748,7 @@ class Client():
                 out_fh.write(files[file])
 
     def create_assessment_session(self, activity, learner, locale=None, max_ttl=120, redirect_reject_url=None,
-                                  reject_message=None):
+                                  reject_message=None, options=None):
         """
             Create a new assessment session for a given activity and learner
 
@@ -748,6 +764,7 @@ class Client():
             :type redirect_reject_url: str
             :param reject_message: Message provided to learner in case ethical warning is rejected
             :type reject_message: str
+            :param options: Options that can be passed to the data object to modify some default properties
             :return: Created session
             :rtype: tesla_ce.models.AssessmentSession
         """
@@ -756,73 +773,31 @@ class Client():
             if learner.consent_accepted is None or learner.consent_rejected is not None:
                 raise TeslaMissingICException()
 
-            if learner.consent.status.startswith('VALID'):
+            if not learner.ic_status.startswith('VALID'):
                 raise TeslaInvalidICException()
 
         # Get the list of instruments and enrolment values
-        instruments = []
         enrolment_obj = {
             'missing_enrolments': False,
             'instruments': {}
         }
         if activity.enabled:
-            instrument_conf = activity.get_learner_instruments(learner)
-            instruments = [inst.instrument.id for inst in instrument_conf]
-
             # Check enrolment status for this learner and activity
-            missing_instruments = [inst.instrument.id for inst in instrument_conf if inst.instrument.requires_enrolment]
-            for enrolment in learner.enrolment_status:
-                if enrolment['instrument_id'] in instruments:
-                    missing_instruments.remove(enrolment['instrument_id'])
-                    enrolment_obj['instruments'][enrolment['instrument_id']] = enrolment
-                    if not enrolment['can_analyse__max']:
-                        enrolment_obj['missing_enrolments'] = True
-            if len(missing_instruments) > 0:
-                enrolment_obj['missing_enrolments'] = True
-                for inst_id in missing_instruments:
-                    enrolment_obj['instruments'][inst_id] = {
-                        "instrument_id": inst_id,
-                        "percentage__min": 0,
-                        "percentage__max": 0,
-                        "can_analyse__min": False,
-                        "can_analyse__max": False,
-                        "pending": [],
-                        "pending_contributions": 0
-                    }
+            enrolment_obj = learner.missing_enrolments(activity.id)
             if enrolment_obj['missing_enrolments']:
                 raise TeslaMissingEnrolmentException(enrolment_obj)
 
         # Set the list of sensors
-        # TODO: Store link between instruments and sensors to models
+        activity_instruments = activity.get_learner_instruments(learner)
         sensors = {}
-        for instrument in instruments:
-            if instrument == 1:
-                # FR
-                # TODO: Check if is online (camera) and/or offline (assessment)
-                if 'camera' not in sensors:
-                    sensors['camera'] = []
-                sensors['camera'].append(1)
-            elif instrument == 2:
-                # KS
-                if 'keyboard' not in sensors:
-                    sensors['keyboard'] = []
-                sensors['keyboard'].append(2)
-            elif instrument == 3:
-                # VR
-                # TODO: Check if is online (microphone) and/or offline (assessment)
-                if 'microphone' not in sensors:
-                    sensors['microphone'] = []
-                sensors['microphone'].append(3)
-            elif instrument == 4:
-                # FA
-                if 'assessment' not in sensors:
-                    sensors['assessment'] = []
-                sensors['assessment'].append(4)
-            elif instrument == 5:
-                # Plagiarism
-                if 'assessment' not in sensors:
-                    sensors['assessment'] = []
-                sensors['assessment'].append(5)
+        instruments = []
+        for instrument in activity_instruments:
+            instruments.append(instrument.instrument_id)
+            inst_sensor = instrument.get_sensors()
+            for sensor in inst_sensor:
+                if sensor not in sensors:
+                    sensors[sensor] = []
+                sensors[sensor].append(instrument.instrument_id)
 
         # Initialize a new Assessment Session
         session = models.AssessmentSession.objects.create(activity=activity, learner=learner)
@@ -834,11 +809,11 @@ class Client():
         # Get the learner token
         token = self.get_learner_token_pair(learner,
                                             [
-                                                '/lapi/v1/verification/{}/{}'.format(
+                                                '/lapi/v1/verification/{}/{}/'.format(
                                                     learner.institution_id, learner.learner_id),
-                                                '/lapi/v1/status/{}/{}'.format(
+                                                '/lapi/v1/status/{}/{}/'.format(
                                                     learner.institution_id, learner.learner_id),
-                                                '/lapi/v1/alert/{}/{}'.format(
+                                                '/lapi/v1/alert/{}/{}/'.format(
                                                     learner.institution_id, learner.learner_id)
                                             ], ttl=15, max_ttl=max_ttl,
                                             filters={
@@ -852,6 +827,12 @@ class Client():
         # Compute the base path for assets
         base_url = '{}'.format(static('web-plugin/web-plugin.js').split('web-plugin.js')[0])
 
+        # Set default options
+        if options is None:
+            options = {}
+        if 'floating_menu_initial_pos' not in options:
+            options['floating_menu_initial_pos'] = 'top-right'
+
         # Update the information
         session_connector_data = {
             'mode': 'verification',
@@ -897,7 +878,8 @@ class Client():
             'dashboard_url': settings.DASHBOARD_URL,
             'launcher': launcher,
             'base_url': base_url,
-            'locale': locale
+            'locale': locale,
+            'options': options
         }
 
         # Store the session data
